﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.Linq;  
using System.Text;
using System.Windows.Forms;
using Signpad;
using Signpad.DataObject;

namespace Signpad
{
    public partial class MainForm : Form
    {
        private SignpadControl control = new SignpadControl();
        private Rectangle lastRect;
        public MainForm()
        /// <summary>
        /// This class provided as a demo to show how to use the Signpad device from a C# application
        /// </summary>
        {
            InitializeComponent();
            this.Load += new EventHandler(MainForm_Load);
            this.Closing += new CancelEventHandler(MainForm_Closing);
            control.PenPressed += new PenPressedHandler(operations_PenPressed);
            this.SetStyle(ControlStyles.AllPaintingInWmPaint | ControlStyles.UserPaint | ControlStyles.DoubleBuffer, true);
            SignpadConfig.Logging = true;
            SignpadHelpers.LogToFile("Signpad App started. Using .NET Framework: " + Environment.Version, SignpadConfig.LogFileName);
            //SignpadConfig.LogFileName = @"C:\Signpad\Signpad\signpad.log";
        }

        void MainForm_Closing(object sender, CancelEventArgs e)
        {
            control.DisconnectDevice();
        }

        void MainForm_Load(object sender, EventArgs e)
        {
            this.ClientSize = new Size(645, 525);
        }

        private void btCapture_Click(object sender, EventArgs e)
        {
            try
            {
                control.StartCapture();                                   
            }
            catch (InvalidOperationException ex)
            {
                ShowError(ex);
            }
            try
            {                
                control.Clear();
            }
            catch (InvalidOperationException ex)
            {
                ShowError(ex);
            }
            // This opens a file dialog for the RUN directory (in this case CometSIGN which I use to store captured signature)
            // I am looking for a bitmap file called signhere.bmp which loads a form on to the signpad device
            // I want to bypass this and load signhere.bmp automatically
            OpenFileDialog openFile1 = new OpenFileDialog();
            openFile1.Filter = "Bitmap Files|*.bmp";
            if (openFile1.ShowDialog() == System.Windows.Forms.DialogResult.OK)                          
            {
                try
                {
                    this.control.SetImage(openFile1.FileName);
                }
                catch (InvalidOperationException ex)
                {
                    ShowError(ex);
                }
            }
        }

  

        private void ShowError(Exception e)
        {
            MessageBox.Show(e.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        void operations_PenPressed(PenPoint args)
        {
            this.Invalidate();
        }


        protected override void OnPaintBackground(PaintEventArgs e)
        {
            base.OnPaintBackground(e);


            e.Graphics.FillRectangle(new SolidBrush(this.BackColor), this.ClientRectangle);
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            base.OnPaint(e);


            SignpadHelpers.DrawPoints(this.control.PenPoints, e.Graphics, Color.Black);

            e.Graphics.DrawRectangle(new Pen(Color.Red), this.lastRect);
        }
 

        private void btSave_Click(object sender, EventArgs e)
        {
            SaveImage();
        }

        private void SaveImage()
        {
            // This loads an input dialog to capture rectangle dimensions (see InputDialog.cs)
            // and draws a rectangle outline around the captured signature on the screen display
            // I know what the dimensions are from the bitmap signhere.bmp and would like to bypass the dialog
            // but still draw the rectangle
            // In the saveLocation line, the captured signature is saved to signatureoutput.jpg in CometSign
            // There will be multiple workstations capturing signatures at invoice time so I need the output file to be unique
            // The filename could be invoicenumber.jpg or terminal.jpg
            // Is there a way to pass these variables from my Comet program
            InputDialog dialog = new InputDialog();
            if (dialog.ShowDialog() == DialogResult.OK)
            {
                Rectangle rect = dialog.GetRectangle();
                this.lastRect = rect;
                Bitmap bitmap = this.control.GetImage(rect);
                string saveLocation = System.Environment.CurrentDirectory + "\\" + "signatureoutput.jpg";
                bitmap.Save(saveLocation, ImageFormat.Jpeg);
                this.Invalidate();
                MessageBox.Show("Saved to " + saveLocation);
            }
        }

        private void btQuit_Click(object sender, EventArgs e)
        {
            control.Clear();
            this.Close();                 
        }       

    }
}
